
#ifndef GRAPHCLUSTERINGLFCO_H
#define GRAPHCLUSTERINGLFCO_H

#include "GraphClustering.h"

namespace Clustering {

class GraphClusteringLFCO : protected GraphClustering {
public:
	GraphClusteringLFCO();

	// Preconditions
	//    Kcost(i,j) ~= 0 ==> Kweight(i,j) ~= 0.
	void Initialize(const gmm::row_matrix<gmm::wsvector<double> >& Kcost,
		const gmm::row_matrix<gmm::wsvector<double> >& Kweight);
	void Initialize(const gmm::dense_matrix<double>& Kcost,
		const gmm::dense_matrix<double>& Kweight);

	void Solve();
	double Objective() const;

	// Return edge variables in the same order as the Edgemap() order.
	// This is the function to use for a theta range of [0,0], where only one
	// solution is computed.
	const std::vector<double>& Solution() const;
	bool IsFractionalSolution() const;

	const std::vector<std::pair<unsigned int, unsigned int> >& Edgemap() const;

protected:
	std::vector<double> obj_a;
	std::vector<double> obj_b;
};

}

#endif

