
#include <cppunit/BriefTestProgressListener.h>
#include <cppunit/CompilerOutputter.h>
#include <cppunit/extensions/TestFactoryRegistry.h>
#include <cppunit/TestResult.h>
#include <cppunit/TestResultCollector.h>
#include <cppunit/TestRunner.h>
#include <cppunit/config/SourcePrefix.h>

#include <boost/random.hpp>

#include <vector>
#include <iostream>
#include <algorithm>
#include <numeric>
#include <limits>
#include <stdlib.h>

#include "GraphClusteringLFCO.h"
#include "GraphClusteringLFCO_test.h"

CPPUNIT_TEST_SUITE_REGISTRATION(GraphClusteringLFCOTest);

// Simple test
void GraphClusteringLFCOTest::Simple() {
	gmm::row_matrix<gmm::wsvector<double> > K(6, 6);

	// Normalized similarity matrix
	//
	// 0.388889 0.388889 0.388889 -0.611111 -0.611111 1.388889 
	// 0.388889 0.388889 0.388889 -0.611111 -0.611111 -0.611111 
	// 0.388889 0.388889 0.388889 -0.611111 -0.611111 -0.611111 
	// -0.611111 -0.611111 -0.611111 0.388889 0.388889 0.388889 
	// -0.611111 -0.611111 -0.611111 0.388889 0.388889 0.388889 
	// 1.388889 -0.611111 -0.611111 0.388889 0.388889 0.388889 
	K(0, 0) = K(0, 1) = K(0, 2) = 0.388889;
	K(0, 3) = K(0, 4) = -0.611111;
	K(0, 5) = 1.388889;
	K(1, 1) = K(1, 2) = 0.388889;
	K(1, 3) = K(1, 4) = K(1, 5) = -0.611111;
	K(2, 2) = 0.388889;
	K(2, 3) = K(2, 4) = K(2, 5) = -0.611111;
	K(3, 3) = K(3, 4) = K(3, 5) = 0.388889;
	K(4, 4) = K(4, 5) = 0.388889;
	K(5, 5) = 0.388889;

	gmm::row_matrix<gmm::wsvector<double> > Kweight(6, 6);
	for (unsigned int row = 0; row < 6; ++row)
		for (unsigned int col = 0; col < 6; ++col)
			Kweight(row, col) = 1.0;

	Clustering::GraphClusteringLFCO gc;
	gc.Initialize(K, Kweight);
	gc.Solve();

	CPPUNIT_ASSERT(true);
}

int main(int argc, char **argv) {
	CPPUNIT_NS::TestResult controller;
	CPPUNIT_NS::TestResultCollector result;
	controller.addListener(&result);        
	CPPUNIT_NS::BriefTestProgressListener progress;
	controller.addListener(&progress);      

	CPPUNIT_NS::TestRunner runner;
	runner.addTest(CPPUNIT_NS::TestFactoryRegistry::getRegistry().makeTest());
	runner.run(controller);

	CPPUNIT_NS::CompilerOutputter outputter(&result, CPPUNIT_NS::stdCOut());
	outputter.write(); 

	return (result.wasSuccessful() ? 0 : 1);
}


