function [score] = rand_score(Ypred, Ytrue);

% Input
%    Ypred: (n,1) integers >= 1, predicted class labels.  Note that the number of
%       classes might disagree with the true number of clusters.
%    Ytrue: (n,1) integers >= 1, true class labels.
%
% Output
%    score: (1,1) scalar >= 0.0, <= 1.0, RAND clustering score.
%
% References
%    [Rand1971], William M. Rand, "Objective Criteria for the Evaluation of
%       Clustering Methods"
Mpred=same_matrices(Ypred);
Mtrue=same_matrices(Ytrue);
a=sum(sum(Mpred.*Mtrue));
b=sum(sum((1-Mpred).*(1-Mtrue)));
c=sum(sum(Mpred.*(1-Mtrue)));
d=sum(sum((1-Mpred).*Mtrue));
score = (a+b)/(a+b+c+d);

function [sameM] = same_matrices(Y);
max_i=max(Y(:));
sameM=zeros(length(Y),length(Y));
for i=1:max_i
	sameM = sameM + double(Y==i)*double(Y==i)';
end

